# BetterString
I just now realised that i have lots to do holy moly fml   
### This is a QoL (Quality of Life) package   
It implements some more functionality to the normal Python str    
**You can use BetterString just like a normal string!**    
Example:      
You can specify how many characters should be uppercase in .upper   
[Docs](https://github.com/DrBumm/BetterString/tree/main/docs)
